# Motorized Devices Control

Motorized Devices Control is an interactive application for controlling EKSMA Optics motorized devices.

## Getting Started

### Installation

```shell
pip install eksma-optics-md-control
```

### Usage

```shell
mdcontrol
```

## License

MIT
